# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The ArcGIS Indoor Positioning toolbox contains tools to create a table
and feature classes for ArcGIS IPS data and a positioning file from
recordings collected by the ArcGIS IPS Setup app that can be used to
enable an indoor positioning system."""
__all__ = ['EnableIndoorPositioning', 'GenerateIndoorPositioningFile']
__alias__ = 'indoorpositioning'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('EnableIndoorPositioning_indoorpositioning', None)
def EnableIndoorPositioning(in_workspace=None):
    """EnableIndoorPositioning_indoorpositioning(in_workspace)

        Creates the feature classes and table necessary for storing ArcGIS IPS
        data in an existing geodatabase.

     INPUTS:
      in_workspace (Workspace):
          The geodatabase where the ArcGIS IPS table and feature classes will be
          created. This can be a file or enterprise geodatabase."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableIndoorPositioning_indoorpositioning(*gp_fixargs((in_workspace,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateIndoorPositioningFile_indoorpositioning', None)
def GenerateIndoorPositioningFile(in_ips_recordings=None, target_ips_positioning=None, in_ips_transitions=None, in_ips_comment=None):
    """GenerateIndoorPositioningFile_indoorpositioning(in_ips_recordings, target_ips_positioning, {in_ips_transitions}, {in_ips_comment})

        Generates a positioning file from ArcGIS IPS Setup survey recordings.

     INPUTS:
      in_ips_recordings (Feature Layer):
          The feature class or feature service that contains ArcGIS IPS Setup
          survey recordings.
      target_ips_positioning (Table View):
          The table or feature service where the generated IPS positioning file
          will be stored.
      in_ips_transitions {Feature Layer}:
          The line feature class that contains the TRANSITION_TYPE,
          VERTICAL_ORDER_FROM, and VERTICAL_ORDER_TO fields that define facility
          entrances and exits. These are used by ArcGIS IPS to improve indoor
          and outdoor localization and switching. The TRANSITION_TYPE field for
          entrances and exits must contain a value of 7 to be used by this tool.
      in_ips_comment {String}:
          The text that will be used to populate the Comment field of the
          positioning file entry in the target_ips_positioning value."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateIndoorPositioningFile_indoorpositioning(*gp_fixargs((in_ips_recordings, target_ips_positioning, in_ips_transitions, in_ips_comment), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject